<?php

namespace Drupal\cf_neighbourhoods\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\Core\Config\Entity\ConfigEntityInterface;
use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Language\LanguageInterface;

/**
 * Defines the neighbourhood entity.
 *
 * @ConfigEntityType(
 *   id = "neighbourhood",
 *   label = @Translation("Neighbourhood"),
 *   handlers = {
 *     "access" = "Drupal\Core\Entity\EntityAccessControlHandler",
 *     "form" = {
 *       "add" = "Drupal\cf_neighbourhoods\NeighbourhoodForm",
 *       "edit" = "Drupal\cf_neighbourhoods\NeighbourhoodForm",
 *       "delete" = "Drupal\cf_neighbourhoods\NeighbourhoodDeleteForm",
 *     },
 *     "list_builder" = "Drupal\cf_neighbourhoods\NeighbourhoodListBuilder"
 *   },
 *   admin_permission = "administer site configuration",
 *   translatable = FALSE,
 *   config_prefix = "hood",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label"
 *   },
 *   links = {
 *     "delete-form" = "/admin/structure/neighbourhoods/{neighbourhood}/delete",
 *     "edit-form" = "/admin/structure/neighbourhoods/{neighbourhood}",
 *     "add-form" = "/admin/structure/neighbourhoods/add",
 *     "collection" = "/admin/structure/neighbourhoods",
 *   },
 *   config_export = {
 *     "id",
 *     "label"
 *   }
 * )
 */

class Neighbourhood extends ConfigEntityBase {

  /**
   * The unique id
   *
   * @var string
   */
  protected $id;

  /**
   * The neighbourhood name.
   *
   * @var string
   */
  protected $label;

  /**
   * {@inheritDoc}
   */
  static function precreate(EntityStorageInterface $storage, array &$values) {
    if (isset($values['label']) and !isset($values['id'])) {
      $values['id'] = self::generateId($values['label']);
    }
  }


  public static function sort(ConfigEntityInterface $a, ConfigEntityInterface $b) {
    return strnatcasecmp($a->label(), $b->label());
  }


  public static function generateId($name) {
    $transliteration = \Drupal::service('transliteration');
    $all = \Drupal::entityTypeManager()->getStorage('neighbourhood')->loadMultiple();
    $name = $transliteration->removeDiacritics($name);
    $name = $transliteration->transliterate($name, LanguageInterface::LANGCODE_SITE_DEFAULT, '', 8);
    $name = mb_strtolower($name);
    $suggestion = preg_replace('@[^a-z0-9_.]+@', '', $name);
    $i=0;
    while (in_array($suggestion, $all)) {
      $i++;
      $suffix = '_'.$i;
      $suggestion = substr_replace($suggestion, $suffix, strlen($suggestion) - strlen($suffix));
    }
    return $suggestion;
  }

}