<?php

namespace Drupal\cf_neighbourhoods\Plugin\migrate\destination;

use Drupal\node\Entity\Node;
use Drupal\migrate\Row;
use Drupal\migrate\Plugin\migrate\destination\EntityContentBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\migrate\Plugin\MigrationInterface;

/**
 * Provides entity destination plugin.
 *
 * @MigrateDestination(
 *   id = "cf_neighbourhoods"
 * )
 */
class Neighbourhoods extends EntityContentBase {

  protected $supportsRollback = FALSE;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition, MigrationInterface $migration = NULL) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $migration,
      $container->get('entity.manager')->getStorage('node'),
      array_keys($container->get('entity.manager')->getBundleInfo('node')),
      $container->get('entity.manager'),
      $container->get('plugin.manager.field.field_type')
    );
  }
  /**
    * {@inheritdoc}
    */
  public function import(Row $row, array $old_destination_id_values = []) {
    $hood_list = $row->getSourceProperty('cforge_neighbourhoods');
    if (empty($hood_list)) {
      \Drupal::messenger()->addWarning('No Neighbourhoods found to migrate: '.implode('; ', $row->getSource()));
      return [];
    }
    foreach (explode("\n", $hood_list) as $hood) {
      $hood = trim($hood);
      if (empty($hood)) {
        continue;
      }
      $hoods = $this->storage->loadByProperties(['label' => $hood]);
      if ($hoods) {
        $hood = reset($hoods);
      }
      else {
        $props = [
          'label' => $hood,
        ];
        $hood = Neighbourhood::create($props);
        $hood->save();
      }
    }
    //just return the last nid because only one is expecteds
    return [$hood->id()];
  }

  /**
   * {@inheritDoc}
   */
  public function getIds() {
    return [
      'id' => [
        'type' => 'string',
        'max_length' => 8,
        'is_ascii' => TRUE,
      ],
    ];
  }

}
