<?php

namespace Drupal\cforge;

use Drupal\Core\Menu\MenuLinkInterface;
use Drupal\Core\Access\AccessResult;

/**
 * Defines a chained translation implementation combining multiple translators.
 */
class DefaultMenuLinkTreeManipulators extends \Drupal\Core\Menu\DefaultMenuLinkTreeManipulators {

  /**
   * Checks access for one menu link instance.
   *
   * @param \Drupal\Core\Menu\MenuLinkInterface $instance
   *   The menu link instance.
   *
   * @return \Drupal\Core\Access\AccessResultInterface
   *   The access result.
   */
  protected function menuLinkCheckAccess(MenuLinkInterface $instance) {
    $url = $instance->getUrlObject();
    if ($this->account->hasPermission('link to any page')) {
      $access_result = AccessResult::allowed();
    }
    elseif(!$url->isRouted()) {
      // Helpdesk link is only visible to committee.
      $access_result = AccessResult::allowedIfHasPermission($this->account, 'administer users');
    }
    elseif (in_array($instance->getMenuName(), ['main', 'footer']) and $url->getRouteName() == 'entity.node.canonical') {
      // handle 'public' a pseudo propert of the node.
      $nid = $url->getRouteParameters()['node'];
      $access_result = AccessResult::allowedIf(cforge_node_get_anonaccess($nid) == $this->account->isAnonymous());
    }
    else {
      $access_result = parent::menuLinkCheckAccess($instance);
    }
    return $access_result->cachePerPermissions();
  }

}
