<?php

namespace Drupal\cforge\Installer;
use \Drupal\node\Entity\Node;

/**
 * Base class to create demo data in any lanaguage.
 */
abstract class DemoUserData {

  public static $firstNames = [];
  public static $lastNames = [];
  public static $names = [];
  public static $streets = [];
  public static $hoods = [];

  /**
   * Get a random neighbourhood.
   */
  public static function randNeighbourhood() {
    static $hoods = [];
    if (empty($hoods)) {
      $hoods = \Drupal::entityTypeManager()
        ->getStorage('neighbourhood')
        ->loadMultiple();
      if (empty($hoods)) {
        trigger_error('no neighbourhoods created yet', E_USER_ERROR);
        return '';
      }
    }
    return $hoods[array_rand($hoods)]->label();
  }

  /**
   * Get a random street.
   */
  public static function randStreet() {
    $key = array_rand(static::$streets);
    return static::$streets[$key];
  }

  /**
   * Get a random phone number.
   */
  public static function randPhone() {
    return '0' . rand(1000, 9999) . ' ' . rand(100000, 999999);
  }

  /**
   * Return a randomised firstname and last name.
   */
  public static function getName() {
    static $firstnames, $lastnames = [];
    if (!$firstnames) {
      $firstnames = static::$firstNames;
      shuffle($firstnames);
    }
    if (!$lastnames) {
      $lastnames = static::$lastNames;
      shuffle($lastnames);
    }
    return [array_pop($firstnames), array_pop($lastnames)];
  }

  /**
   * Return the number of demo user names.
   */
  public static function countUsers() {
    return count(static::$firstNames);
  }

  // Get a random location in the Geneva area.
  public static function randLocation($north = 84, $east = 180, $south = -84, $west= -180) {
    return 'POINT('.static::between($east, $west).' '.static::between($north, $south).')';
  }

  public static function between($a, $b) {
     return rand((float)$a*10000, (float)$b*10000)/10000;
  }

}
